==> haskell-wai-conduit-3.0.0.4-361-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-conduit
version:              3.0.0.4
visibility:           public
id:                   wai-conduit-3.0.0.4-27g5tGz3EwIOPCR6ZQSS9
key:                  wai-conduit-3.0.0.4-27g5tGz3EwIOPCR6ZQSS9
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.

category:             Web, Conduit
abi:                  6f7bfae3243575a04733e03af44787e9
exposed:              True
exposed-modules:      Network.Wai.Conduit
import-dirs:          /usr/lib/ghc-9.0.1/site-local/wai-conduit-3.0.0.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/wai-conduit-3.0.0.4
hs-libraries:         HSwai-conduit-3.0.0.4-27g5tGz3EwIOPCR6ZQSS9
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    conduit-1.3.4.1-APoT7S8i9fNAuDbLjFbyiG
    http-types-0.12.3-GbuqI8dbngCJpBlxNWvblX transformers-0.5.6.2
    wai-3.2.3-3b05xVWcdqf1yAlmx9fZeh

haddock-interfaces:   /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html:         /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-conduit-3.0.0.4-362-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-conduit
version:              3.0.0.4
visibility:           public
id:                   wai-conduit-3.0.0.4-JnY9oFiDgDVEbegTkabOuD
key:                  wai-conduit-3.0.0.4-JnY9oFiDgDVEbegTkabOuD
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.

category:             Web, Conduit
abi:                  548eb78c34449a0f2522728ab85a6031
exposed:              True
exposed-modules:      Network.Wai.Conduit
import-dirs:          /usr/lib/ghc-9.0.1/site-local/wai-conduit-3.0.0.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/wai-conduit-3.0.0.4
hs-libraries:         HSwai-conduit-3.0.0.4-JnY9oFiDgDVEbegTkabOuD
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    conduit-1.3.4.2-3a4oLt2zoluJkPoJvBjFCf
    http-types-0.12.3-GbuqI8dbngCJpBlxNWvblX transformers-0.5.6.2
    wai-3.2.3-3b05xVWcdqf1yAlmx9fZeh

haddock-interfaces:   /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html:         /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
